@@ -142,6 +142,8 @@ def map_queries(
     min_score=40,
     strata=-1,
     accurate_mapq=False,
+    use_alignment_score=False,
+    skip_alignment=False,
     max_hits=100,
     semiglobal_alignment=False,
     gap_open_penalty=6,
@@ -149,7 +151,7 @@ def map_queries(
     blocksize_filtration=512,
     blocksize_validation=512,
     query_buffersize=1000000,
-    hits_buffersize=1000000,
+    postprocessing_buffersize=100000,
     cpu=False,
     statspath=None,
     no_output=False,
@@ -174,13 +176,14 @@ def map_queries(
             gap_open_penalty=gap_open_penalty,
             gap_extend_penalty=gap_extend_penalty,
             semiglobal_alignment=semiglobal_alignment, threads=threads,
-            buffersize=hits_buffersize, paired=paired,
+            buffersize=postprocessing_buffersize, paired=paired,
             insert_size=insert_size, insert_size_error=insert_size_error,
-            accurate_mapq=accurate_mapq)
+            accurate_mapq=accurate_mapq, use_alignment_score=use_alignment_score,
+            skip_alignment=skip_alignment)
 
         writing_future = pool.submit(
             _write_hits, bam_queue, references, read_group, paired=paired,
-            use_xa=use_xa) if not no_output else pool.submit(eat_queue, bam_queue)
+            use_xa=use_xa, no_cigars=skip_alignment) if not no_output else pool.submit(eat_queue, bam_queue)
 
         stats.start_timer("overall_running_time")
 
@@ -294,6 +297,7 @@ def _map_queries(
         stats.stop_timer("plain_mapping_running_time")
 
         hit_queue.put((queries, Hits(hit_positions, hit_scores, query_hits_pos)))
+        logging.debug("hit queue: {} items".format(hit_queue.qsize()))
 
         del cl_queries
         del cl_queries_sizes
@@ -320,11 +324,13 @@ def _postprocess_hits(
     gap_open_penalty=6,
     gap_extend_penalty=1,
     threads=1,
-    buffersize=1000000,
+    buffersize=100000,
     paired=False,
     insert_size=220,
     insert_size_error=50,
-    accurate_mapq=False):
+    accurate_mapq=False,
+    use_alignment_score=False,
+    skip_alignment=False):
     """Worker for postprocessing."""
 
     processed = 0
@@ -347,8 +353,11 @@ def _postprocess_hits(
             threads=threads, buffersize=buffersize,
             paired=paired, insert_size=insert_size,
             insert_size_error=insert_size_error,
-            accurate_mapq=accurate_mapq):
+            accurate_mapq=accurate_mapq,
+            use_alignment_score=use_alignment_score,
+            skip_alignment=skip_alignment):
             bam_queue.put((queries, postprocessed_hits))
+            logging.debug("bam queue: {} items".format(bam_queue.qsize()))
         stats.stop_timer("postprocessing")
         hit_queue.task_done()
         processed += queries.count
@@ -361,7 +370,8 @@ def _write_hits(
     references,
     read_group,
     paired=False,
-    use_xa=False
+    use_xa=False,
+    no_cigars=False
     ):
     """Worker for writing."""
 
@@ -374,7 +384,7 @@ def _write_hits(
         logging.debug("writing")
         queries, postprocessed_hits = item
         stats.start_timer("writing")
-        peanut.output.print_sam(queries, postprocessed_hits, paired, references.names, use_xa)
+        peanut.output.print_sam(queries, postprocessed_hits, paired, references.names, use_xa, no_cigars=no_cigars)
         del postprocessed_hits
         stats.stop_timer("writing")
         bam_queue.task_done()
@@ -423,14 +433,15 @@ def argument_parser():
     group = mapping.add_argument_group("execution parameters")
     group.add_argument("--threads", type=int, default=1, metavar="N", help="CPU-Threads for postprocessing and alignment (default 1).")
     group.add_argument("--query-buffer", "--read-buffer", "-b", metavar="N", type=int, default=1000000, help="How many queries (reads) should be mapped in parallel (default 1000000).")
-    group.add_argument("--hits-buffer", "--hb", type=int, metavar="N", default=5000000, help="How many hits should be postprocessed in parallel (default 5000000).")
+    group.add_argument("--postprocessing-buffer", "--pb", type=int, metavar="N", help="How many queries should be postprocessed in parallel (per default the same as --query-buffer).")
 
     group = mapping.add_argument_group("sensitivity parameters")
     group.add_argument("--semiglobal", "-S", action="store_true", help="Calculate a semi-global instead of local alignment.")
-    group.add_argument("--percent-identity", "-i", type=int, default=50, metavar="N", help="Minimum percent identity for mapping to a position. This is the fraction of matches in the alignment starting at the mapping position.")
+    group.add_argument("--percent-identity", "-i", type=int, default=80, metavar="N", help="Minimum percent identity for mapping to a position. This is the fraction of matches in the alignment starting at the mapping position (default 80).")
     group.add_argument("--strata", "-s", default=1, metavar="N", help="How many strata (hits of the same quality) should be reported for each read (default: 1). Use --strata all to report all strata.")
     group.add_argument("--max-hits", "-m", type=int, default=100, metavar="N", help="Maximum number of hits per read (default 100). Regardless of strata value, this limits the number of records per read in the bam file.")
     group.add_argument("--accurate-mapq", action="store_true", help="Do not set all mapping qualities to zero if a read aligns ambiguously to multiple positions. The default behaviour ensures compatibility to downstream tools like GATK.")
+    group.add_argument("--use-alignment-score", "--as", action="store_true", help="Use the aligment score with affine gap costs for sorting hits into strata (see above). This will be slightly more compute intensive as more alignments will have to be calculated.")
     group.add_argument("--insert-size", "--isize", type=int, default=220, metavar="I", help="Expected insert size for read and mate (default 220). See --insert-size-error for effects.")
     group.add_argument("--insert-size-error", "--ierr", type=int, default=50, metavar="E", help="Maximum deviation from expected insert size (default 50). Insert sizes within [I-Em, I+E] will lead to read and mate being marked as properly paired.")
     group.add_argument("--gap-open-penalty", "-O", default=2, type=int, metavar="N", help="Gap open penalty (default 2).")
@@ -439,6 +450,7 @@ def argument_parser():
     group = mapping.add_argument_group("output format parameters")
     group.add_argument("--read-group", "--rgid", nargs="+", metavar="ENTRY", help="The read group (e.g. --read-group ID:XY SM:21347 PL:Illumina). At least ID is required.")
     group.add_argument("--no-xa", action="store_true", help="Do not use the XA tag for reporting alternative alignments (this can lead to larger output and increased running time).")
+    group.add_argument("--no-alignments", action="store_true", help="Do not report the actual alignments. This omits the calculation of the CIGAR strings and therefore saves a lot of time.")
 
     group = mapping.add_argument_group("technical parameters")
     group.add_argument("--blocksize-filtration", "--bf", type=int, default=512, metavar="N",
@@ -491,6 +503,8 @@ def main(profile=False):
             if paired and query_buffer % 2:
                 query_buffer += 1
 
+            postprocessing_buffer = query_buffer if args.postprocessing_buffer is None else args.postprocessing_buffer
+
             if args.reference.endswith("hdf5"):
                 index = args.reference
             else:
@@ -503,6 +517,8 @@ def main(profile=False):
                 min_score=args.percent_identity,
                 strata=strata,
                 accurate_mapq=args.accurate_mapq,
+                use_alignment_score=args.use_alignment_score,
+                skip_alignment=args.no_alignments,
                 max_hits=args.max_hits,
                 semiglobal_alignment=args.semiglobal,
                 gap_open_penalty=args.gap_open_penalty,
@@ -510,7 +526,7 @@ def main(profile=False):
                 blocksize_filtration=args.blocksize_filtration,
                 blocksize_validation=args.blocksize_validation,
                 query_buffersize=query_buffer,
-                hits_buffersize=args.hits_buffer,
+                postprocessing_buffersize=postprocessing_buffer,
                 statspath=args.stats,
                 threads=args.threads,
                 read_group=args.read_group,
